from flask import make_response, jsonify
from app import db

def handle_db_commit(data, operation_type='operation'):
    operation_messages = {
        'create': 'Room created successfully',
        'update': 'Room updated successfully',
        'delete': 'Room deleted successfully'
    }
    try:
        if operation_type == 'create':
            db.session.add(data)
        elif operation_type == 'delete':
            db.session.delete(data)
        db.session.commit()
        message = operation_messages.get(operation_type, 'Operation successful')
        return make_response(jsonify({'message': message, "status": "Success"}), 200)
    except Exception as e:
        db.session.rollback()
        return make_response(jsonify({'message': str(e), "status": "error"}), 500)
    
def paginate_query(query, page, per_page):
    paginated = query.paginate(page=page, per_page=per_page, error_out=False)
    data = {
        'total_count': paginated.total,
        'total_pages': paginated.pages,
        'start_index': (page - 1) * per_page + 1,
        'end_index': min(page * per_page, paginated.total),
        'page': page,
        'per_page': per_page
    }
    return paginated.items, data